@@ -14,9 +14,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
-from PyQt5.Qt import QSize
+from PyQt5.QtCore import QSize
 from PyQt5.QtWidgets import QPushButton
-#pylint: enable=no-name-in-module
 
 from .styleable import make_styleable
 
